<?php

namespace FiloBlu\OrderAdditionalData\Block\Adminhtml\Order\Tab\View;

use Magento\Backend\Block\Template;
use Magento\Backend\Block\Template\Context;
use Magento\Backend\Block\Widget\Tab\TabInterface;
use Magento\Framework\Api\SimpleDataObjectConverter;
use Magento\Framework\Registry;

/**
 * Class AdditionalData
 * @package FiloBlu\OrderAdditionalData\Block\Adminhtml\Ordere\Tab\View
 */
class AdditionalData extends Template implements TabInterface
{
    /**
     * @var string
     */
    protected $_template = 'tab/view/additional_data.phtml';
    /**
     * @var Registry
     */
    protected $_coreRegistry;

    /**
     * AdditionalData constructor.
     * @param Context $context
     * @param Registry $registry
     * @param array $data
     */
    public function __construct(
        Context $context,
        Registry $registry,
        array $data = []
    ) {
        parent::__construct($context, $data);
        $this->_coreRegistry = $registry;
    }

    public function getOrderIncrementId()
    {
        return $this->getOrder()->getIncrementId();
    }

    public function getOrder()
    {
        return $this->_coreRegistry->registry('current_order');
    }

    public function getTabLabel()
    {
        return __('Additional Data');
    }

    public function getTabTitle()
    {
        return __('Additional Data');
    }

    public function canShowTab()
    {
        return true;
    }

    public function isHidden()
    {
        return false;
    }

    /**
     * @return mixed
     */
    public function getLastSectionId()
    {
        $sectionsKeys = array_keys($this->getSections());
        return end($sectionsKeys);
    }

    /**
     * @return array
     */
    public function getSections()
    {
        return [
            'general'         => [
                'pay_exchangerate'                   => [
                    'editable' => false,
                    'label'    => 'Pay Exchange Rate'
                ],
                'fbnetsuite_theoric_shipping_amount' => [
                    'editable' => true,
                    'label'    => 'Theoric Ahipping Amount'
                ],
            ],
            'checkout'        => [
                'checkout_invoice'               => [
                    'editable' => true,
                    'label'    => 'Invoice'
                ],
                'checkout_invoice_fiscal_code'   => [
                    'editable' => true,
                    'label'    => 'Fiscal Code'
                ],
                'checkout_invoice_vat_number'    => [
                    'editable' => true,
                    'label'    => 'VAT Number'
                ],
                'dni'                            => [
                    'editable' => true,
                    'label'    => 'DNI'

                ],
                'checkout_invoice_business_name' => [
                    'editable' => true,
                    'label'    => 'Business Name'

                ],
                'checkout_invoice_pec'           => [
                    'editable' => true,
                    'label'    => 'PEC'

                ],
                'checkout_invoice_sdi'           => [
                    'editable' => true,
                    'label'    => 'SDI'
                ],

            ],
            'mailchimp'       => [
                'mailchimp_campaign_id'        => [
                    'editable' => false,
                    'label'    => 'Campaign Id'
                ],
                'mailchimp_abandonedcart_flag' => [
                    'editable' => false,
                    'label'    => 'Abandonedcart Flag'
                ],
                'mailchimp_landing_page'       => [
                    'editable' => false,
                    'label'    => 'Landing page'
                ],
                'mailchimp_flag'               => [
                    'editable' => false,
                    'label'    => 'Flag'
                ]
            ],
            'pickup_in_store' => [
                'pickup_in_store_id'                    => ['editable' => false],
                'pickup_in_store_email'                 => ['editable' => false],
                'pickup_in_store_confirm_date'          => ['editable' => false],
                'pickup_in_store_hash'                  => ['editable' => false],
                'pickup_in_store_confirm_received_date' => ['editable' => false],
            ],

        ];
    }

    /**
     * @param $snakeCaseString
     * @param null $remove
     * @return string
     */
    public function labelize($snakeCaseString, $remove = null)
    {
        if ($remove) {
            $snakeCaseString = str_replace($remove, '', $snakeCaseString);
        }
        return ucfirst(
            trim(
                SimpleDataObjectConverter::camelCaseToSnakeCase(
                    str_replace('_', ' ', $snakeCaseString)
                )
            )
        );
    }

    /**
     * @return string
     */
    public function getSubmitUrl()
    {
        return $this->getUrl('filoblu_order_additional_data/order/save', ['id' => $this->getOrderId()]);
    }

    /**
     * @return mixed
     */
    public function getOrderId()
    {
        return $this->getOrder()->getEntityId();
    }
}
