<?php
/**
 * Copyright © 2016 Filoblu S.r.l. All rights reserved.
 */

namespace FiloBlu\OrderAdditionalData\Observer;

use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Sales\Api\Data\ShipmentInterface;
use Magento\Sales\Api\OrderRepositoryInterface;

/**
 * Observer on Order Status Update
 */
class ShipmentSave implements ObserverInterface
{

    /**
     * @var OrderRepositoryInterface
     */
    protected $orderRepository;

    /**
     * ShipmentSave constructor.
     * @param OrderRepositoryInterface $orderRepository
     */
    public function __construct(
        OrderRepositoryInterface $orderRepository
    ) {
        $this->orderRepository = $orderRepository;
    }

    /**
     * Save Order Increment ID in Shipment Object
     *
     * @param Observer $observer
     * @return ShipmentInterface
     */
    public function execute(Observer $observer)
    {
        $shipment = $observer->getEvent()->getShipment();
        $order_increment_id = $shipment->getData('order_increment_id');
        if ($order_increment_id === null) {
            $order = $this->orderRepository->get($shipment->getOrderId());
            $shipment->setData('order_increment_id', $order->getIncrementId());
        }
        return $shipment;
    }
}
